# Python extensions

[![PyPI Version](http://img.shields.io/pypi/v/qwert.svg)](https://pypi.python.org/pypi/qwert/)

Python extensions:

- list_fn
- dict_fn
- file_fn


## Installation

``` console
$ pip3 install qwert
```


## Usage

``` python
from qwert import list_fn
from qwert import dict_fn
from qwert import file_fn
```

